@@ -1,6 +1,4 @@
 from .token import force_obtain_id_token
 from .testing import TestStorageBucket
 
-__all__ = [
-    "force_obtain_id_token", "TestStorageBucket"
-]
+__all__ = ["force_obtain_id_token", "TestStorageBucket"]
