@@ -3,9 +3,4 @@ from .inspect import SQLAIntrospector
 from .base import Base, Registry
 from .encode import SqlaDeclarativeEncoder
 
-__all__ = [
-    "Database",
-    "Base", "Registry",
-    "SQLAIntrospector",
-    "SqlaDeclarativeEncoder"
-]
+__all__ = ["Database", "Base", "Registry", "SQLAIntrospector", "SqlaDeclarativeEncoder"]
